@@ -237,12 +237,17 @@ OsinfoEntity *osinfo_list_find_by_id(OsinfoList *list, const gchar *id)
  */
 void osinfo_list_add(OsinfoList *list, OsinfoEntity *entity)
 {
+    OsinfoEntity *preexisting;
     g_return_if_fail(G_TYPE_CHECK_INSTANCE_TYPE(entity, list->priv->elementType));
 
     g_object_ref(entity);
+    preexisting = osinfo_list_find_by_id(list, osinfo_entity_get_id(entity));
+    if (preexisting != NULL) {
+        g_ptr_array_remove(list->priv->array, preexisting);
+    }
     g_ptr_array_add(list->priv->array, entity);
-    g_hash_table_insert(list->priv->entities,
-                        (gchar *)osinfo_entity_get_id(entity), entity);
+    g_hash_table_replace(list->priv->entities,
+                         (gchar *)osinfo_entity_get_id(entity), entity);
 }
 
 
@@ -411,6 +416,8 @@ static OsinfoList *osinfo_list_new_same(OsinfoList *sourceOne,
  * Construct a new list that is filled with elements from @source
  *
  * Returns: (transfer full): a copy of the list
+ *
+ * Since: 0.2.2
  */
 OsinfoList *osinfo_list_new_copy(OsinfoList *source)
 {
@@ -430,6 +437,8 @@ OsinfoList *osinfo_list_new_copy(OsinfoList *source)
  * match @filter
  *
  * Returns: (transfer full): a filtered copy of the list
+ *
+ * Since: 0.2.2
  */
 OsinfoList *osinfo_list_new_filtered(OsinfoList *source, OsinfoFilter *filter)
 {
@@ -450,6 +459,8 @@ OsinfoList *osinfo_list_new_filtered(OsinfoList *source, OsinfoFilter *filter)
  * that are present in both @sourceOne and @sourceTwo.
  *
  * Returns: (transfer full): an intersection of the two lists
+ *
+ * Since: 0.2.2
  */
 OsinfoList *osinfo_list_new_intersection(OsinfoList *sourceOne,
                                          OsinfoList *sourceTwo)
@@ -472,6 +483,8 @@ OsinfoList *osinfo_list_new_intersection(OsinfoList *sourceOne,
  * the same type.
  *
  * Returns: (transfer full): a union of the two lists
+ *
+ * Since: 0.2.2
  */
 OsinfoList *osinfo_list_new_union(OsinfoList *sourceOne,
                                   OsinfoList *sourceTwo)
@@ -483,12 +496,3 @@ OsinfoList *osinfo_list_new_union(OsinfoList *sourceOne,
                           OSINFO_LIST(sourceTwo));
     return newList;
 }
-
-
-/*
- * Local variables:
- *  indent-tabs-mode: nil
- *  c-indent-level: 4
- *  c-basic-offset: 4
- * End:
- */
